@@ -34,7 +34,11 @@ sub errn (&$$) {
 sub conf {
 	my %app;
 
-	@app{qw{ app_key app_secret access_token access_secret }} = split ':', $ENV{'DROPBOX_AUTH'} || '';
+	if (exists $ENV{'DROPBOX_AUTH2'}) {
+		@app{qw{ oauth2 access_token }} = (1, $ENV{'DROPBOX_AUTH2'});
+	} else {
+		@app{qw{ app_key app_secret access_token access_secret }} = split ':', $ENV{'DROPBOX_AUTH'} || '';
+	}
 
 	%app = ()
 		if grep { not defined or not length } values %app;
